@@ -1,12 +1,13 @@
 // Copyright (C) 2023 The Qt Company Ltd.
 // SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only
 
-#ifndef QABSTRACTDATAPROXY_H
-#define QABSTRACTDATAPROXY_H
+#ifndef QTGRAPHS_QABSTRACTDATAPROXY_H
+#define QTGRAPHS_QABSTRACTDATAPROXY_H
 
 #include <QtCore/qobject.h>
 #include <QtCore/qscopedpointer.h>
 #include <QtGraphs/qgraphsglobal.h>
+#include <QtQmlIntegration/qqmlintegration.h>
 
 QT_BEGIN_NAMESPACE
 
@@ -18,6 +19,8 @@ class Q_GRAPHS_EXPORT QAbstractDataProxy : public QObject
     Q_DECLARE_PRIVATE(QAbstractDataProxy)
     Q_CLASSINFO("RegisterEnumClassesUnscoped", "false")
     Q_PROPERTY(QAbstractDataProxy::DataType type READ type CONSTANT)
+    QML_NAMED_ELEMENT(AbstractDataProxy)
+    QML_UNCREATABLE("Uncreatable base type")
 
 public:
     enum class DataType {
